==> sight_21.0.0.orig.tar.gz: sight-21.0.0/modules/ui/base/SToolBar.cpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2021 IRCAD France
 * Copyright (C) 2012-2020 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "SToolBar.hpp"

#include <service/macros.hpp>

namespace sight::module::ui::base
{

SToolBar::SToolBar() noexcept
{
}

//-----------------------------------------------------------------------------

SToolBar::~SToolBar() noexcept
{
}

//-----------------------------------------------------------------------------

void SToolBar::starting()
{
    this->create();
}

//-----------------------------------------------------------------------------

void SToolBar::stopping()
{
    this->destroy();
}

//-----------------------------------------------------------------------------

void SToolBar::configuring()
{
    this->initialize();
}

//-----------------------------------------------------------------------------

void SToolBar::updating()
{
}

//-----------------------------------------------------------------------------

void SToolBar::info(std::ostream& _sstream)
{
}

}

==> sight_21.1.1.orig.tar.gz: sight-21.1.1/modules/ui/base/SToolBar.cpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2021 IRCAD France
 * Copyright (C) 2012-2020 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "SToolBar.hpp"

#include <service/macros.hpp>

namespace sight::module::ui::base
{

SToolBar::SToolBar() noexcept
{
}

//-----------------------------------------------------------------------------

SToolBar::~SToolBar() noexcept
{
}

//-----------------------------------------------------------------------------

void SToolBar::starting()
{
    this->create();
}

//-----------------------------------------------------------------------------

void SToolBar::stopping()
{
    this->destroy();
}

//-----------------------------------------------------------------------------

void SToolBar::configuring()
{
    this->initialize();
}

//-----------------------------------------------------------------------------

void SToolBar::updating()
{
}

//-----------------------------------------------------------------------------

void SToolBar::info(std::ostream&)
{
}

}
